@@ -2,16 +2,18 @@
 Version Manager API
 """
 
+from core_main_app.commons import exceptions as exceptions
 from core_main_app.components.version_manager import api as version_manager_api
 from core_main_registry_app.components.custom_resource import api as custom_resource_api
-from core_main_app.commons import exceptions as exceptions
 
 
-def set_current(version):
+# NOTE: access control by main set current
+def set_current(version, request):
     """Set the current version of the object, then saves it.
 
     Args:
         version:
+        request:
 
     Returns:
 
@@ -20,4 +22,4 @@ def set_current(version):
         raise exceptions.ApiError(
             "Please set custom resources to template before setting it to current."
         )
-    version_manager_api.set_current(version)
+    version_manager_api.set_current(version, request=request)
